:mod:`basc_py4chan` – 4chan Python Library
==========================================

:mod:`basc_py4chan` gives access to 4chan from a clean Python interface.


Basic Usage
-----------

.. automodule:: basc_py4chan

Methods
-------

    .. autofunction:: basc_py4chan.get_boards

    .. autofunction:: basc_py4chan.get_all_boards
